nxp-pac

Crates

git

Versions

lpc55s69_cm33_core1

Flavors

Loader

Struct Loader 

#[repr(transparent)]
pub struct Loader(pub u32);
Contains an optional loader to load into CTRL0/1 in steps to perform a set of operations.

Tuple Fields

0: u32

Implementations

Source

impl Loader

pub const fn count(&self) -> u8

Number of control pairs to load 0 relative (so 1 means load 1). write 1 means Does one op - does not iterate, write N means N control pairs to load

pub const fn set_count(&mut self, val: u8)

Number of control pairs to load 0 relative (so 1 means load 1). write 1 means Does one op - does not iterate, write N means N control pairs to load

pub const fn ctrlbpair(&self) -> Ctrlbpair

Which bank-pair the offset CTRLOFF is within. This must be 0 if only 2-up. Does not matter which bank is used as this is loaded when not performing an operation.

pub const fn set_ctrlbpair(&mut self, val: Ctrlbpair)

Which bank-pair the offset CTRLOFF is within. This must be 0 if only 2-up. Does not matter which bank is used as this is loaded when not performing an operation.

pub const fn ctrloff(&self) -> u16

DWord Offset of CTRL pair to load next.

pub const fn set_ctrloff(&mut self, val: u16)

DWord Offset of CTRL pair to load next.