#[repr(transparent)]pub struct Res0(pub u32);Expand description
Result register 0
Tuple Fields
0: u32Implementations
Sourceimpl Res0
impl Res0
Sourcepub const fn reg_value(&self) -> u32
pub const fn reg_value(&self) -> u32
Register to hold working result (from multiplier, adder/xor, etc). Is not normally written or read by application, but is available when accelerator not busy.
Sourcepub const fn set_reg_value(&mut self, val: u32)
pub const fn set_reg_value(&mut self, val: u32)
Register to hold working result (from multiplier, adder/xor, etc). Is not normally written or read by application, but is available when accelerator not busy.